@@ -1,7 +1,5 @@
-PythonMax = max
-from numpy import all, any, isfinite, inf, nan, ndarray, string_, zeros_like, ones, array_equal, array, copy, asscalar, \
-where, ravel, asfarray, prod, asarray, isscalar, atleast_1d, isinf
-import numpy as np
+__docformat__ = "restructuredtext en"
+from numpy import *
 from oologfcn import *
 from oographics import Graphics
 from setDefaultIterFuncs import setDefaultIterFuncs, denyingStopFuncs
@@ -36,9 +34,9 @@ class oomatrix:
     def __init__(self):
         pass
     def matMultVec(self, x, y):
-        return np.dot(x, y) if not isspmatrix(x) else x._mul_sparse_matrix(csr_matrix(y.reshape((y.size, 1)))).A.flatten() 
+        return dot(x, y) if not isspmatrix(x) else x._mul_sparse_matrix(csr_matrix(y.reshape((y.size, 1)))).A.flatten() 
     def matmult(self, x, y):
-        return np.dot(x, y)
+        return dot(x, y)
         #return asarray(x) ** asarray(y)
     def dotmult(self, x, y):
         return x * y
@@ -92,7 +90,6 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
     contol = 1e-6
     discrtol = 1e-5 # tolerance required for discrete constraints 
     fTol = None
-    rTol = 1e-8#used in interalg
 
     minIter = 0
     minFunEvals = 0
@@ -256,7 +253,7 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
         if asfarray(f).size != 1: self.err('unexpected f size. The function should be redefined in OO child class, inform OO developers')
         return f
 
-    def fill(self, newProb, sameConstraints=True):
+    def inspire(self, newProb, sameConstraints=True):
         # fills some fields of new prob with old prob values
         newProb.castFrom = self.probType
 
@@ -357,7 +354,7 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
                     fTol = self.ftol
                 self.fTol = self.ftol = fTol
                 appender = lambda arg: [appender(elem) for elem in arg] if isinstance(arg, (ndarray, list, tuple, set))\
-                else ((arg.oofun*(fTol/arg.tol) if arg.tol != fTol and arg.tol != 0 else arg.oofun) if arg.isConstraint else arg)
+                else ((arg.oofun*(fTol/arg.tol) if arg.tol != 0 else arg.oofun) if arg.isConstraint else arg)
                 EQs = []
                 for eq in equations:
                     rr = appender(eq)
@@ -367,9 +364,7 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
                         EQs.append(rr)
                 #EQs = [((elem.oofun*(fTol/elem.tol) if elem.tol != 0 else elem.oofun) if elem.isConstraint else elem) for elem in equations]
                 if self.probType in ('SLE', 'LLSP'): self.C = EQs
-                elif self.probType in ('NLSP', 'SNLE'): 
-                    self.f = EQs
-#                    self.user.F = EQs
+                elif self.probType in ('NLSP', 'SNLE'): self.f = EQs
                 else: raise OpenOptException('bug in OO kernel')
             else:
                 F = [self.f]
@@ -435,14 +430,14 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
                     
             self.probDep = probDep
             self.x0 = Tmp
-            self._stringVars = set()
+            self._categoricalVars = set()
             for key, val in self.x0.items():
                 #if key.domain is not None and key.domain is not bool and key.domain is not 'bool':
                 if type(val) in (str, string_):
-                    self._stringVars.add(key)
+                    self._categoricalVars.add(key)
                     key.formAuxDomain()
-                    self.x0[key] = key.aux_domain[val]#searchsorted(key.aux_domain, val, 'left')
-                elif key.fields == () and key.domain is not None and key.domain is not bool and key.domain is not 'bool' \
+                    self.x0[key] = searchsorted(key.aux_domain, val, 'left')
+                elif key.domain is not None and key.domain is not bool and key.domain is not 'bool' \
                 and key.domain is not int and key.domain is not 'int' and val not in key.domain:
                     self.x0[key] = key.domain[0]
             
@@ -498,14 +493,6 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
 
             self.constraints = set(self.constraints)
             for v in self._x0.keys():
-#                if v.fields != ():
-#                    v.aux_domain = Copy(v.domain)
-##                    # TODO: mb rework it
-##                    ind_numeric = [j for j, elem in enumerate(v.aux_domain[0]) if type(elem) not in (str, np.str_)]
-##                    if len(ind_numeric):
-##                        ind_first_numeric = ind_numeric[0]
-##                        v.aux_domain.sort(key = lambda elem: elem[ind_first_numeric])
-#                    v.domain = np.arange(len(v.domain))
                 if not array_equal(v.lb, -inf):
                     self.constraints.add(v >= v.lb)
                 if not array_equal(v.ub, inf):
@@ -573,9 +560,9 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
                     v.domain.sort()
                     self.constraints.update([v >= v.domain[0], v <= v.domain[-1]])
                     if hasattr(v, 'aux_domain'):
-                        self.constraints.add(v <= len(v.aux_domain)-1)
+                        self.constraints.add(v - (len(v.aux_domain)-1)<=0)
                     
-#            for v in self._stringVars:
+#            for v in self._categoricalVars:
 #                if isFixed(v):
 #                    ind = searchsorted(v.aux_domain, p._x0[v], 'left')
 #                    if v.aux_domain
@@ -633,7 +620,7 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
                     self.handleConstraint(c, *handleConstraint_args)
 
             if len(b) != 0:
-                self.A, self.b = Vstack(A), Hstack([asfarray(elem).flatten() for elem in b])#Vstack(b).flatten()
+                self.A, self.b = Vstack(A), Hstack([ravel(elem) for elem in b])#Vstack(b).flatten()
                 if hasattr(self.b, 'toarray'): self.b = self.b.toarray()
             if len(beq) != 0:
                 self.Aeq, self.beq = Vstack(Aeq), Hstack([ravel(elem) for elem in beq])#Vstack(beq).flatten()
@@ -654,8 +641,7 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
             if self.probType in ['LLSP', 'LLAVP', 'LUNP']: arr.append('D')
             for fn in arr:
                 if not hasattr(self, fn): continue
-                tmp = getattr(self, fn)
-                fv = asarray(tmp) if not isspmatrix(tmp) else tmp.A
+                fv = asarray(getattr(self, fn))
                 if any(isfinite(fv)):
                     self.x0 = zeros(fv.size)
                     break
@@ -704,6 +690,8 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
         probtol = self.contol
         f, tol = c.oofun, c.tol
         _lb, _ub = c.lb, c.ub
+        #f0, lb_0, ub_0 = f, copy(_lb), copy(_ub)
+        lb_0, ub_0 = copy(_lb), copy(_ub)
         Name = f.name
         
         dep = set([f]) if f.is_oovar else f._getDep()
@@ -979,7 +967,7 @@ class NonLinProblem(baseProblem, nonLinFuncs, Args):
             if not self.solver.iterfcnConnected:
                 if self.solver.funcForIterFcnConnection == 'f':
                     if not hasattr(self, 'f_iter'):
-                        self.f_iter = PythonMax(self.n, 4)
+                        self.f_iter = max((self.n, 4))
                 else:
                     if not hasattr(self, 'df_iter'):
                         self.df_iter = True
