@@ -323,10 +323,7 @@ def runProbSolver(p_, solver_str_or_instance=None, *args, **kwargs):
 
     # Solving finished
     if hasattr(p, '_bestPoint') and not any(isnan(p._bestPoint.x)) and p.probType != 'ODE':
-        try:
-            p.iterfcn(p._bestPoint)
-        except isSolved:
-            pass
+        p.iterfcn(p._bestPoint)
     if p.probType != 'EIG':
         if not hasattr(p, 'xf') and not hasattr(p, 'xk'): p.xf = p.xk = ones(p.n)*nan
         if hasattr(p, 'xf') and (not hasattr(p, 'xk') or array_equal(p.xk, p.x0)): p.xk = p.xf
@@ -366,7 +363,7 @@ def runProbSolver(p_, solver_str_or_instance=None, *args, **kwargs):
     #if not hasattr(p, 'xf'): p.xf = p.xk
     if type(p.xf) in (list, tuple) or isscalar(p.xf): p.xf = asarray(p.xf)
     p.xf = p.xf.flatten()
-    p.rf = p.getMaxResidual(p.xf) if p.probType not in ('IP', 'ODE') else p.rk
+    p.rf = p.getMaxResidual(p.xf) if not p.probType == 'IP' else p.rk
 
     if not p.isFeasible and p.istop > 0: p.istop = -100-p.istop/1000.0
     
@@ -404,9 +401,6 @@ def runProbSolver(p_, solver_str_or_instance=None, *args, **kwargs):
 
 ##################################################################
 def finalTextOutput(p, r):
-    if type(p.msg) == ndarray: # from fmincon etc
-        msg = asarray(p.msg.flatten(),int).tolist()
-        p.msg = ''.join(chr(c) for c in msg)
     if p.iprint >= 0:
         if len(p.msg):  
             p.disp("istop: " + str(r.istop) + ' (' + p.msg +')')
